==> events-0.26.0-sources.jar: software/amazon/awscdk/services/events/EventRuleImportProps.java <==
package software.amazon.awscdk.services.events;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:57:18.480Z")
public interface EventRuleImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    java.lang.String getEventRuleArn();
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    void setEventRuleArn(final java.lang.String value);

    /**
     * @return a {@link Builder} of {@link EventRuleImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EventRuleImportProps}
     */
    final class Builder {
        private java.lang.String _eventRuleArn;

        /**
         * Sets the value of EventRuleArn
         * @param value The value of the event rule Amazon Resource Name (ARN), such as
arn:aws:events:us-east-2:123456789012:rule/example.
         * @return {@code this}
         */
        public Builder withEventRuleArn(final java.lang.String value) {
            this._eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EventRuleImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EventRuleImportProps build() {
            return new EventRuleImportProps() {
                private java.lang.String $eventRuleArn = java.util.Objects.requireNonNull(_eventRuleArn, "eventRuleArn is required");

                @Override
                public java.lang.String getEventRuleArn() {
                    return this.$eventRuleArn;
                }

                @Override
                public void setEventRuleArn(final java.lang.String value) {
                    this.$eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.EventRuleImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public java.lang.String getEventRuleArn() {
            return this.jsiiGet("eventRuleArn", java.lang.String.class);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public void setEventRuleArn(final java.lang.String value) {
            this.jsiiSet("eventRuleArn", java.util.Objects.requireNonNull(value, "eventRuleArn is required"));
        }
    }
}

==> events-0.27.0-sources.jar: software/amazon/awscdk/services/events/EventRuleImportProps.java <==
package software.amazon.awscdk.services.events;

@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:35:09.571Z")
public interface EventRuleImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    java.lang.String getEventRuleArn();

    /**
     * @return a {@link Builder} of {@link EventRuleImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EventRuleImportProps}
     */
    final class Builder {
        private java.lang.String _eventRuleArn;

        /**
         * Sets the value of EventRuleArn
         * @param value The value of the event rule Amazon Resource Name (ARN), such as
arn:aws:events:us-east-2:123456789012:rule/example.
         * @return {@code this}
         */
        public Builder withEventRuleArn(final java.lang.String value) {
            this._eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EventRuleImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EventRuleImportProps build() {
            return new EventRuleImportProps() {
                private final java.lang.String $eventRuleArn = java.util.Objects.requireNonNull(_eventRuleArn, "eventRuleArn is required");

                @Override
                public java.lang.String getEventRuleArn() {
                    return this.$eventRuleArn;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("eventRuleArn", om.valueToTree(this.getEventRuleArn()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.EventRuleImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public java.lang.String getEventRuleArn() {
            return this.jsiiGet("eventRuleArn", java.lang.String.class);
        }
    }
}
